@@ -2,7 +2,7 @@
 #define __PARADOX_H__
 
 #define PX_USE_RECODE 0
-#define PX_USE_ICONV 0
+#define PX_USE_ICONV 1
 
 #include <stdio.h>
 #if PX_USE_RECODE
@@ -150,7 +150,7 @@ struct px_stream {
 	union {
 		FILE *fp;
 		void *stream;
-#if PX_HAVE_GSF
+#if HAVE_GSF
 		GsfInput *gsfin;
 		GsfOutput *gsfout;
 #endif
