@@ -6,7 +6,7 @@
 #include <string.h>
 #include <fcntl.h>
 #include <time.h>
-#include "paradox.h"
+#include "paradox-gsf.h"
 #include "px_intern.h"
 #include "px_memory.h"
 #include "px_io.h"
